diff --git a/web/pgadmin/misc/dependencies/static/js/dependencies.js b/web/pgadmin/misc/dependencies/static/js/dependencies.js
index bab26019f..7c3fde57f 100644
--- a/web/pgadmin/misc/dependencies/static/js/dependencies.js
+++ b/web/pgadmin/misc/dependencies/static/js/dependencies.js
@@ -230,7 +230,8 @@ define('misc.dependencies', [
               $msgContainer.text(gettext('Failed to retrieve data from the server.'));
             });
         }
-      } if (msg != '') {
+      }
+      if (msg != '') {
         $msgContainer.text(msg);
         $msgContainer.removeClass('d-none');
         if (!$gridContainer.hasClass('d-none')) {
diff --git a/web/pgadmin/misc/dependents/static/js/dependents.js b/web/pgadmin/misc/dependents/static/js/dependents.js
index 5f6007f1d..7c5f3b575 100644
--- a/web/pgadmin/misc/dependents/static/js/dependents.js
+++ b/web/pgadmin/misc/dependents/static/js/dependents.js
@@ -236,7 +236,8 @@ define('misc.dependents', [
               $msgContainer.text(gettext('Failed to retrieve data from the server.'));
             });
         }
-      } if (msg != '') {
+      }
+      if (msg != '') {
         $msgContainer.text(msg);
         $msgContainer.removeClass('d-none');
         if (!$gridContainer.hasClass('d-none')) {
diff --git a/web/pgadmin/utils/driver/abstract.py b/web/pgadmin/utils/driver/abstract.py
index f66613ad5..217419e6e 100644
--- a/web/pgadmin/utils/driver/abstract.py
+++ b/web/pgadmin/utils/driver/abstract.py
@@ -67,7 +67,7 @@ class BaseDriver(object):
         pass
 
     @abstractmethod
-    def gc(self):
+    def gc_timeout(self):
         pass
 
 
diff --git a/web/pgadmin/utils/driver/psycopg2/__init__.py b/web/pgadmin/utils/driver/psycopg2/__init__.py
index 439e56f47..f6734ee77 100644
--- a/web/pgadmin/utils/driver/psycopg2/__init__.py
+++ b/web/pgadmin/utils/driver/psycopg2/__init__.py
@@ -197,7 +197,7 @@ class Driver(BaseDriver):
                 str(sid) in self.managers[session.sid]:
             del self.managers[session.sid][str(sid)]
 
-    def gc(self):
+    def gc_timeout(self):
         """
         Release the connections for the sessions, which have not pinged the
         server for more than config.MAX_SESSION_IDLE_TIME.
diff --git a/web/pgadmin/utils/driver/psycopg2/server_manager.py b/web/pgadmin/utils/driver/psycopg2/server_manager.py
index 64eac1d93..45d7b4e04 100644
--- a/web/pgadmin/utils/driver/psycopg2/server_manager.py
+++ b/web/pgadmin/utils/driver/psycopg2/server_manager.py
@@ -148,24 +148,24 @@ class ServerManager(object):
 
         return res
 
-    def ServerVersion(self):
+    def server_version(self):
         return self.ver
 
     @property
     def version(self):
         return self.sversion
 
-    def MajorVersion(self):
+    def major_version(self):
         if self.sversion is not None:
             return int(self.sversion / 10000)
         raise Exception(gettext("Information is not available."))
 
-    def MinorVersion(self):
+    def minor_version(self):
         if self.sversion:
             return int(int(self.sversion / 100) % 100)
         raise Exception(gettext("Information is not available."))
 
-    def PatchVersion(self):
+    def patch_version(self):
         if self.sversion:
             return int(int(self.sversion / 100) / 100)
         raise Exception(gettext("Information is not available."))
diff --git a/web/pgadmin/utils/javascript/javascript_bundler.py b/web/pgadmin/utils/javascript/javascript_bundler.py
index 4b8c249b0..dec0e9cd5 100644
--- a/web/pgadmin/utils/javascript/javascript_bundler.py
+++ b/web/pgadmin/utils/javascript/javascript_bundler.py
@@ -24,24 +24,24 @@ class JavascriptBundler:
     """Builds Javascript bundle files by delegating to webpack"""
 
     def __init__(self):
-        self.jsState = JsState.NONE
+        self.js_state = JsState.NONE
 
     def bundle(self):
         try:
             try_building_js()
-            self.jsState = JsState.NEW
+            self.js_state = JsState.NEW
         except OSError:
             webdir_path()
             generatedJavascriptDir = os.path.join(
                 webdir_path(), 'pgadmin', 'static', 'js', 'generated')
             if os.path.exists(generatedJavascriptDir) and \
                     os.listdir(generatedJavascriptDir):
-                self.jsState = JsState.OLD
+                self.js_state = JsState.OLD
             else:
-                self.jsState = JsState.NONE
+                self.js_state = JsState.NONE
 
     def report(self):
-        return self.jsState
+        return self.js_state
 
 
 @contextmanager
diff --git a/web/pgadmin/utils/menu.py b/web/pgadmin/utils/menu.py
index c4d74e90e..3d43b3d2e 100644
--- a/web/pgadmin/utils/menu.py
+++ b/web/pgadmin/utils/menu.py
@@ -26,15 +26,15 @@ class Panel(object):
         self.content = content
         self.width = width
         self.height = height
-        self.isIframe = isIframe
-        self.showTitle = showTitle
-        self.isCloseable = isCloseable
-        self.isPrivate = isPrivate
+        self.is_iframe = isIframe
+        self.show_title = showTitle
+        self.is_closeable = isCloseable
+        self.is_private = isPrivate
         self.icon = icon
         self.data = data
         self.events = events
         self.limit = limit
-        self.canHide = canHide
+        self.can_hide = canHide
         if priority is None:
             global PRIORITY
             PRIORITY += 100
